@@ -9,6 +9,7 @@ from __future__ import absolute_import, print_function
 from behave import given, when, then
 
 from pptx import Presentation
+from pptx.chart.chart import Chart
 from pptx.dml.color import RGBColor
 from pptx.enum.dml import MSO_FILL, MSO_THEME_COLOR
 from pptx.enum.shapes import MSO_SHAPE, MSO_SHAPE_TYPE
@@ -26,6 +27,27 @@ def given_a_connector(context):
     context.shape = sld.shapes[4]
 
 
+@given('a graphic frame')  # shouldn't matter, but this one contains a table
+def given_a_table(context):
+    prs = Presentation(test_pptx('shp-common-props'))
+    sld = prs.slides[0]
+    context.shape = sld.shapes[2]
+
+
+@given('a graphic frame containing a chart')
+def given_a_graphic_frame_containing_a_chart(context):
+    prs = Presentation(test_pptx('shp-access-chart'))
+    sld = prs.slides[0]
+    context.shape = sld.shapes[0]
+
+
+@given('a graphic frame containing a table')
+def given_a_graphic_frame_containing_a_table(context):
+    prs = Presentation(test_pptx('shp-access-chart'))
+    sld = prs.slides[1]
+    context.shape = sld.shapes[0]
+
+
 @given('a group shape')
 def given_a_group_shape(context):
     prs = Presentation(test_pptx('shp-common-props'))
@@ -47,21 +69,14 @@ def given_a_shape(context):
     context.shape = sld.shapes[0]
 
 
-@given('a table')
-def given_a_table(context):
-    prs = Presentation(test_pptx('shp-common-props'))
-    sld = prs.slides[0]
-    context.shape = sld.shapes[2]
-
-
 @given('a {shape_type} on a slide')
 def given_a_shape_on_a_slide(context, shape_type):
     shape_idx = {
-        'shape':       0,
-        'picture':     1,
-        'table':       2,
-        'group shape': 3,
-        'connector':   4,
+        'shape':         0,
+        'picture':       1,
+        'graphic frame': 2,
+        'group shape':   3,
+        'connector':     4,
     }[shape_type]
     prs = Presentation(test_pptx('shp-common-props'))
     sld = prs.slides[0]
@@ -96,8 +111,8 @@ def given_ref_to_chevron_shape(context):
 # when ====================================================
 
 @when("I add a text box to the slide's shape collection")
-def when_add_text_box(context):
-    shapes = context.sld.shapes
+def when_I_add_a_text_box(context):
+    shapes = context.slide.shapes
     x, y = (Inches(1.00), Inches(2.00))
     cx, cy = (Inches(3.00), Inches(1.00))
     sp = shapes.add_textbox(x, y, cx, cy)
@@ -105,8 +120,8 @@ def when_add_text_box(context):
 
 
 @when("I add an auto shape to the slide's shape collection")
-def when_add_auto_shape(context):
-    shapes = context.sld.shapes
+def when_I_add_an_auto_shape(context):
+    shapes = context.slide.shapes
     x, y = (Inches(1.00), Inches(2.00))
     cx, cy = (Inches(3.00), Inches(4.00))
     sp = shapes.add_shape(MSO_SHAPE.ROUNDED_RECTANGLE, x, y, cx, cy)
@@ -116,11 +131,11 @@ def when_add_auto_shape(context):
 @when("I change the left and top of the {shape_type}")
 def when_I_change_the_position_of_the_shape(context, shape_type):
     left, top = {
-        'shape':        (692696, 1339552),
-        'picture':     (1835696, 2711152),
-        'table':       (2978696, 4082752),
-        'group shape': (4121696, 5454352),
-        'connector':   (5264696, 6825952),
+        'shape':          (692696, 1339552),
+        'picture':       (1835696, 2711152),
+        'graphic frame': (2978696, 4082752),
+        'group shape':   (4121696, 5454352),
+        'connector':     (5264696, 6825952),
     }[shape_type]
     shape = context.shape
     shape.left = left
@@ -130,17 +145,22 @@ def when_I_change_the_position_of_the_shape(context, shape_type):
 @when("I change the width and height of the {shape_type}")
 def when_I_change_the_size_of_the_shape(context, shape_type):
     width, height = {
-        'shape':        (692696, 1339552),
-        'picture':     (1835696, 2711152),
-        'table':       (2978696, 4082752),
-        'group shape': (4121696, 5454352),
-        'connector':   (5264696, 6825952),
+        'shape':          (692696, 1339552),
+        'picture':       (1835696, 2711152),
+        'graphic frame': (2978696, 4082752),
+        'group shape':   (4121696, 5454352),
+        'connector':     (5264696, 6825952),
     }[shape_type]
     shape = context.shape
     shape.width = width
     shape.height = height
 
 
+@when("I get the chart from its graphic frame")
+def when_I_get_the_chart_from_its_graphic_frame(context):
+    context.chart = context.shape.chart
+
+
 @when("I set the fill type to background")
 def when_set_fill_type_to_background(context):
     context.shape.fill.background()
@@ -238,11 +258,11 @@ def then_the_shape_has_textframe_status(context, has_textframe_status):
 @then('I can get the id of the {shape_type}')
 def then_I_can_get_the_id_of_the_shape(context, shape_type):
     expected_id = {
-        'shape':        2,
-        'picture':      3,
-        'table':        4,
-        'group shape':  9,
-        'connector':   11,
+        'shape':         2,
+        'picture':       3,
+        'graphic frame': 4,
+        'group shape':   9,
+        'connector':    11,
     }[shape_type]
     assert context.shape.id == expected_id
 
@@ -250,25 +270,30 @@ def then_I_can_get_the_id_of_the_shape(context, shape_type):
 @then('I can get the name of the {shape_type}')
 def then_I_can_get_the_name_of_the_shape(context, shape_type):
     expected_name = {
-        'shape':       'Rounded Rectangle 1',
-        'picture':     'Picture 2',
-        'table':       'Table 3',
-        'group shape': 'Group 8',
-        'connector':   'Elbow Connector 10',
+        'shape':         'Rounded Rectangle 1',
+        'picture':       'Picture 2',
+        'graphic frame': 'Table 3',
+        'group shape':   'Group 8',
+        'connector':     'Elbow Connector 10',
     }[shape_type]
     shape = context.shape
     msg = "expected shape name '%s', got '%s'" % (shape.name, expected_name)
     assert shape.name == expected_name, msg
 
 
+@then('the chart is a Chart object')
+def then_the_chart_is_a_Chart_object(context):
+    assert isinstance(context.chart, Chart)
+
+
 @then('the left and top of the {shape_type} match their new values')
 def then_left_and_top_of_shape_match_new_values(context, shape_type):
     expected_left, expected_top = {
-        'shape':        (692696, 1339552),
-        'picture':     (1835696, 2711152),
-        'table':       (2978696, 4082752),
-        'group shape': (4121696, 5454352),
-        'connector':   (5264696, 6825952),
+        'shape':          (692696, 1339552),
+        'picture':       (1835696, 2711152),
+        'graphic frame': (2978696, 4082752),
+        'group shape':   (4121696, 5454352),
+        'connector':     (5264696, 6825952),
     }[shape_type]
     shape = context.shape
     assert shape.left == expected_left, 'got left: %s' % shape.left
@@ -278,25 +303,32 @@ def then_left_and_top_of_shape_match_new_values(context, shape_type):
 @then('the left and top of the {shape_type} match their known values')
 def then_left_and_top_of_shape_match_known_values(context, shape_type):
     expected_left, expected_top = {
-        'shape':       (1339552,  692696),
-        'picture':     (2711152, 1835696),
-        'table':       (4082752, 2978696),
-        'group shape': (5454352, 4121696),
-        'connector':   (6825952, 5264696),
+        'shape':         (1339552,  692696),
+        'picture':       (2711152, 1835696),
+        'graphic frame': (4082752, 2978696),
+        'group shape':   (5454352, 4121696),
+        'connector':     (6825952, 5264696),
     }[shape_type]
     shape = context.shape
     assert shape.left == expected_left, 'got left: %s' % shape.left
     assert shape.top == expected_top, 'got top: %s' % shape.top
 
 
+@then('the shape {has_or_not} a chart')
+def then_the_shape_has_or_not_a_chart(context, has_or_not):
+    expected_bool = {'has': True, 'does not have': False}[has_or_not]
+    shape = context.shape
+    assert shape.has_chart is expected_bool
+
+
 @then('the width and height of the {shape_type} match their known values')
 def then_width_and_height_of_shape_match_known_values(context, shape_type):
     expected_width, expected_height = {
-        'shape':       (928192, 914400),
-        'picture':     (914400, 945232),
-        'table':       (993304, 914400),
-        'group shape': (914400, 914400),
-        'connector':   (986408, 828600),
+        'shape':         (928192, 914400),
+        'picture':       (914400, 945232),
+        'graphic frame': (993304, 914400),
+        'group shape':   (914400, 914400),
+        'connector':     (986408, 828600),
     }[shape_type]
     shape = context.shape
     assert shape.width == expected_width, 'got width: %s' % shape.width
@@ -306,11 +338,11 @@ def then_width_and_height_of_shape_match_known_values(context, shape_type):
 @then('the width and height of the {shape_type} match their new values')
 def then_width_and_height_of_shape_match_new_values(context, shape_type):
     expected_width, expected_height = {
-        'shape':        (692696, 1339552),
-        'picture':     (1835696, 2711152),
-        'table':       (2978696, 4082752),
-        'group shape': (4121696, 5454352),
-        'connector':   (5264696, 6825952),
+        'shape':          (692696, 1339552),
+        'picture':       (1835696, 2711152),
+        'graphic frame': (2978696, 4082752),
+        'group shape':   (4121696, 5454352),
+        'connector':     (5264696, 6825952),
     }[shape_type]
     shape = context.shape
     assert shape.width == expected_width, 'got width: %s' % shape.width
