@@ -7,12 +7,12 @@ Gherkin step implementations for slide-related features.
 from __future__ import absolute_import
 
 from behave import given, when, then
-from hamcrest import assert_that, equal_to, is_
 
 from pptx import Presentation
 from pptx.parts.slide import (
     _SlidePlaceholder, _SlidePlaceholders, _SlideShapeTree
 )
+from pptx.shapes.graphfrm import GraphicFrame
 from pptx.shapes.picture import Picture
 from pptx.shapes.shape import BaseShape
 
@@ -23,9 +23,8 @@ from .helpers import saved_pptx_path, test_pptx
 
 @given('a blank slide')
 def given_a_blank_slide(context):
-    context.prs = Presentation()
-    slide_layout = context.prs.slide_layouts[6]
-    context.sld = context.prs.slides.add_slide(slide_layout)
+    context.prs = Presentation(test_pptx('sld-blank'))
+    context.slide = context.prs.slides[0]
 
 
 @given('a slide')
@@ -35,8 +34,8 @@ def given_a_slide(context):
     context.sld = context.prs.slides.add_slide(slide_layout)
 
 
-@given('a slide having three shapes')
-def given_a_slide_having_three_shapes(context):
+@given('a slide having six shapes')
+def given_a_slide_having_six_shapes(context):
     presentation = Presentation(test_pptx('sld-access-shapes'))
     context.slide = presentation.slides[0]
 
@@ -71,13 +70,20 @@ def when_I_add_a_slide_based_on_a_layout(context):
 
 @then('each slide shape is of the appropriate type')
 def then_each_slide_shape_is_of_the_appropriate_type(context):
-    shapes = context.shapes
-    expected_types = [_SlidePlaceholder, _SlidePlaceholder, Picture]
-    for idx, shape in enumerate(shapes):
-        assert type(shape) == expected_types[idx], (
+
+    def assertShapeType(shape, expected_type):
+        assert type(shape) is expected_type, (
             "got \'%s\'" % type(shape).__name__
         )
 
+    shapes = context.shapes
+    assertShapeType(shapes[0], _SlidePlaceholder)
+    assertShapeType(shapes[1], _SlidePlaceholder)
+    assertShapeType(shapes[2], Picture)
+    assertShapeType(shapes[3], GraphicFrame)
+    assertShapeType(shapes[4], GraphicFrame)
+    assertShapeType(shapes[5], GraphicFrame)
+
 
 @then('I can access a shape by index')
 def then_can_access_shape_by_index(context):
@@ -126,7 +132,7 @@ def then_can_iterate_over_the_shapes(context):
     for shape in shapes:
         actual_count += 1
         assert isinstance(shape, BaseShape)
-    assert actual_count == 3
+    assert actual_count == 6
 
 
 @then('I can iterate over the slide placeholders')
@@ -139,12 +145,12 @@ def then_can_iterate_over_the_slide_placeholders(context):
     assert actual_count == 2
 
 
-@then('the length of the shape collection is 3')
-def then_len_of_shape_collection_is_3(context):
+@then('the length of the shape collection is 6')
+def then_len_of_shape_collection_is_6(context):
     slide = context.slide
     shapes = slide.shapes
-    assert len(shapes) == 3, (
-        'expected len(shapes) of 3, got %s' % len(shapes)
+    assert len(shapes) == 6, (
+        'expected len(shapes) of 6, got %s' % len(shapes)
     )
 
 
@@ -161,7 +167,7 @@ def then_len_of_placeholder_collection_is_2(context):
 @then('the pptx file contains a single slide')
 def then_pptx_file_contains_single_slide(context):
     context.prs = prs = Presentation(saved_pptx_path)
-    assert_that(len(prs.slides), is_(equal_to(1)))
+    assert len(prs.slides) == 1
 
 
 @then('the index of each shape matches its position in the sequence')
@@ -177,6 +183,6 @@ def then_index_of_each_shape_matches_its_position_in_the_sequence(context):
 def then_the_layout_has_been_applied_to_the_slide(context):
     prs = context.prs
     shapes = prs.slides[0].shapes
-    assert len(shapes) == 2
+    assert len(shapes) == 2, 'expected 2 shapes, got %d' % len(shapes)
     assert shapes[0].name == 'Title 1'
     assert shapes[1].name == 'Subtitle 2'
