@@ -8,61 +8,39 @@ from __future__ import absolute_import
 
 from warnings import warn
 
+from .chart import ChartPart
+from ..enum.shapes import PP_PLACEHOLDER
 from ..opc.constants import CONTENT_TYPE as CT, RELATIONSHIP_TYPE as RT
-from ..opc.package import Part
+from ..opc.package import XmlPart
 from ..opc.packuri import PackURI
-from ..oxml import parse_xml_bytes
-from ..oxml.ns import nsmap, _nsmap, qn
-from ..oxml.shared import Element, SubElement
-from ..oxml.shapes.shared import ST_Direction, ST_PlaceholderType
+from ..oxml.ns import qn
+from ..oxml.simpletypes import ST_Direction
+from ..oxml.parts.slide import CT_Slide
+from ..oxml.shapes.graphfrm import CT_GraphicalObjectFrame
 from ..shapes.autoshape import AutoShapeType
 from ..shapes.placeholder import BasePlaceholder, BasePlaceholders
 from ..shapes.shapetree import BaseShapeFactory, BaseShapeTree
 from ..util import lazyproperty
 
 
-class BaseSlide(Part):
+class BaseSlide(XmlPart):
     """
     Base class for slide parts, e.g. slide, slideLayout, slideMaster,
     notesSlide, notesMaster, and handoutMaster.
     """
-    def __init__(self, partname, content_type, element, package):
-        super(BaseSlide, self).__init__(
-            partname, content_type, element=element, package=package
-        )
-
-    @classmethod
-    def load(cls, partname, content_type, blob, package):
-        slide_elm = parse_xml_bytes(blob)
-        slide = cls(partname, content_type, slide_elm, package)
-        return slide
-
     @property
     def name(self):
         """
         Internal name of this slide.
         """
-        cSld = self._element.cSld
-        return cSld.get('name', default='')
-
-    @property
-    def part(self):
-        """
-        Part of the parent protocol, "children" of the slide will not know
-        the part that contains them so must ask their parent object. That
-        chain of delegation ends here for slide child objects.
-        """
-        return self
+        return self._element.cSld.name
 
     @property
     def spTree(self):
         """
         Reference to ``<p:spTree>`` element for this slide
         """
-        spTree_lst = self._element.xpath(
-            './p:cSld/p:spTree', namespaces=_nsmap
-        )
-        return spTree_lst[0]
+        return self._element.cSld.spTree
 
     def _add_image(self, img_file):
         """
@@ -80,16 +58,26 @@ class Slide(BaseSlide):
     """
     Slide part. Corresponds to package files ppt/slides/slide[1-9][0-9]*.xml.
     """
-    @classmethod
-    def new(cls, slidelayout, partname, package):
+    def add_chart_part(self, chart_type, chart_data):
         """
-        Return a new slide based on *slidelayout* and having *partname*,
+        Return the rId of a new |ChartPart| object containing a chart of
+        *chart_type*, displaying *chart_data*, and related to the slide
+        containing this shape tree.
+        """
+        chart_part = ChartPart.new(chart_type, chart_data, self.package)
+        rId = self.relate_to(chart_part, RT.CHART)
+        return rId
+
+    @classmethod
+    def new(cls, slide_layout, partname, package):
+        """
+        Return a new slide based on *slide_layout* and having *partname*,
         created from scratch.
         """
-        slide_elm = cls._minimal_element()
+        slide_elm = CT_Slide.new()
         slide = cls(partname, CT.PML_SLIDE, slide_elm, package)
-        slide.shapes.clone_layout_placeholders(slidelayout)
-        slide.relate_to(slidelayout, RT.SLIDE_LAYOUT)
+        slide.shapes.clone_layout_placeholders(slide_layout)
+        slide.relate_to(slide_layout, RT.SLIDE_LAYOUT)
         return slide
 
     @lazyproperty
@@ -127,26 +115,6 @@ class Slide(BaseSlide):
         warn(msg, UserWarning, stacklevel=2)
         return self.slide_layout
 
-    @staticmethod
-    def _minimal_element():
-        """
-        Return element containing the minimal XML for a slide, based on what
-        is required by the XMLSchema.
-        """
-        sld = Element('p:sld', nsmap('a', 'p', 'r'))
-        SubElement(sld, 'p:cSld')
-        SubElement(sld.cSld, 'p:spTree')
-        SubElement(sld.cSld.spTree, 'p:nvGrpSpPr')
-        SubElement(sld.cSld.spTree.nvGrpSpPr, 'p:cNvPr')
-        SubElement(sld.cSld.spTree.nvGrpSpPr, 'p:cNvGrpSpPr')
-        SubElement(sld.cSld.spTree.nvGrpSpPr, 'p:nvPr')
-        SubElement(sld.cSld.spTree, 'p:grpSpPr')
-        sld.cSld.spTree.nvGrpSpPr.cNvPr.set('id', '1')
-        sld.cSld.spTree.nvGrpSpPr.cNvPr.set('name', '')
-        SubElement(sld, 'p:clrMapOvr')
-        SubElement(sld.clrMapOvr, 'a:masterClrMapping')
-        return sld
-
 
 class SlideCollection(object):
     """
@@ -221,6 +189,21 @@ class _SlideShapeTree(BaseShapeTree):
     is the backmost in z-order and the last shape is topmost. Supports indexed
     access, len(), index(), and iteration.
     """
+    def add_chart(self, chart_type, x, y, cx, cy, chart_data):
+        """
+        Add a new chart of *chart_type* to the slide, positioned at (*x*,
+        *y*), having size (*cx*, *cy*), and depicting *chart_data*.
+        *chart_type* is one of the :ref:`XlChartType` enumeration values.
+        *chart_data* is a |ChartData| object populated with the categories
+        and series values for the chart. Note that a |GraphicFrame| shape
+        object is returned, not the |Chart| object contained in that graphic
+        frame shape. The chart object may be accessed using the :attr:`chart`
+        property of the returned |GraphicFrame| object.
+        """
+        rId = self.part.add_chart_part(chart_type, chart_data)
+        graphic_frame = self._add_chart_graphic_frame(rId, x, y, cx, cy)
+        return graphic_frame
+
     def add_picture(self, image_file, left, top, width=None, height=None):
         """
         Add picture shape displaying image in *image_file*, where
@@ -248,16 +231,18 @@ class _SlideShapeTree(BaseShapeTree):
 
     def add_table(self, rows, cols, left, top, width, height):
         """
-        Add table shape with the specified number of *rows* and *cols* at the
-        specified position with the specified size. *width* is evenly
-        distributed between the *cols* columns of the new table. Likewise,
-        *height* is evenly distributed between the *rows* rows created.
+        Add a |GraphicFrame| object containing a table with the specified
+        number of *rows* and *cols* and the specified position and size.
+        *width* is evenly distributed between the columns of the new table.
+        Likewise, *height* is evenly distributed between the rows. Note that
+        the ``.table`` property on the returned |GraphicFrame| shape must be
+        used to access the enclosed |Table| object.
         """
         graphicFrame = self._add_graphicFrame_containing_table(
             rows, cols, left, top, width, height
         )
-        table = self._shape_factory(graphicFrame)
-        return table
+        graphic_frame = self._shape_factory(graphicFrame)
+        return graphic_frame
 
     def add_textbox(self, left, top, width, height):
         """
@@ -306,6 +291,29 @@ class _SlideShapeTree(BaseShapeTree):
                 return self._shape_factory(elm)
         return None
 
+    def _add_chart_graphicFrame(self, rId, x, y, cx, cy):
+        """
+        Add a new ``<p:graphicFrame>`` element to this shape tree having the
+        specified position and size and referring to the chart part
+        identified by *rId*.
+        """
+        shape_id = self._next_shape_id
+        name = 'Chart %d' % (shape_id-1)
+        graphicFrame = CT_GraphicalObjectFrame.new_chart_graphicFrame(
+            shape_id, name, rId, x, y, cx, cy
+        )
+        self._spTree.append(graphicFrame)
+        return graphicFrame
+
+    def _add_chart_graphic_frame(self, rId, x, y, cx, cy):
+        """
+        Return a |GraphicFrame| object having the specified position and size
+        and referring to the chart part identified by *rId*.
+        """
+        graphicFrame = self._add_chart_graphicFrame(rId, x, y, cx, cy)
+        graphic_frame = self._shape_factory(graphicFrame)
+        return graphic_frame
+
     def _add_graphicFrame_containing_table(self, rows, cols, x, y, cx, cy):
         """
         Return a newly added ``<p:graphicFrame>`` element containing a table
@@ -395,22 +403,22 @@ class _SlideShapeTree(BaseShapeTree):
         """
         basename = {
             # BODY is named 'Notes Placeholder' in a notes master
-            ST_PlaceholderType.BODY:      'Text Placeholder',
-            ST_PlaceholderType.CHART:     'Chart Placeholder',
-            ST_PlaceholderType.CLIP_ART:  'ClipArt Placeholder',
-            ST_PlaceholderType.CTR_TITLE: 'Title',
-            ST_PlaceholderType.DGM:       'SmartArt Placeholder',
-            ST_PlaceholderType.DT:        'Date Placeholder',
-            ST_PlaceholderType.FTR:       'Footer Placeholder',
-            ST_PlaceholderType.HDR:       'Header Placeholder',
-            ST_PlaceholderType.MEDIA:     'Media Placeholder',
-            ST_PlaceholderType.OBJ:       'Content Placeholder',
-            ST_PlaceholderType.PIC:       'Picture Placeholder',
-            ST_PlaceholderType.SLD_IMG:   'Slide Image Placeholder',
-            ST_PlaceholderType.SLD_NUM:   'Slide Number Placeholder',
-            ST_PlaceholderType.SUB_TITLE: 'Subtitle',
-            ST_PlaceholderType.TBL:       'Table Placeholder',
-            ST_PlaceholderType.TITLE:     'Title',
+            PP_PLACEHOLDER.BODY:         'Text Placeholder',
+            PP_PLACEHOLDER.CHART:        'Chart Placeholder',
+            PP_PLACEHOLDER.BITMAP:       'ClipArt Placeholder',
+            PP_PLACEHOLDER.CENTER_TITLE: 'Title',
+            PP_PLACEHOLDER.ORG_CHART:    'SmartArt Placeholder',
+            PP_PLACEHOLDER.DATE:         'Date Placeholder',
+            PP_PLACEHOLDER.FOOTER:       'Footer Placeholder',
+            PP_PLACEHOLDER.HEADER:       'Header Placeholder',
+            PP_PLACEHOLDER.MEDIA_CLIP:   'Media Placeholder',
+            PP_PLACEHOLDER.OBJECT:       'Content Placeholder',
+            PP_PLACEHOLDER.PICTURE:      'Picture Placeholder',
+            # PP_PLACEHOLDER.SLIDE_IMAGE:  'Slide Image Placeholder',
+            PP_PLACEHOLDER.SLIDE_NUMBER: 'Slide Number Placeholder',
+            PP_PLACEHOLDER.SUBTITLE:     'Subtitle',
+            PP_PLACEHOLDER.TABLE:        'Table Placeholder',
+            PP_PLACEHOLDER.TITLE:        'Title',
         }[ph_type]
 
         # prefix rootname with 'Vertical ' if orient is 'vert'
@@ -419,7 +427,7 @@ class _SlideShapeTree(BaseShapeTree):
 
         # increment numpart as necessary to make name unique
         numpart = id - 1
-        names = self._spTree.xpath('//p:cNvPr/@name', namespaces=_nsmap)
+        names = self._spTree.xpath('//p:cNvPr/@name')
         while True:
             name = '%s %d' % (basename, numpart)
             if name not in names:
