@@ -119,7 +119,7 @@ class AdjustmentCollection(object):
             return []
         davs = AutoShapeType.default_adjustment_values(prstGeom.prst)
         adjustments = [Adjustment(name, def_val) for name, def_val in davs]
-        self._update_adjustments_with_actuals(adjustments, prstGeom.gd)
+        self._update_adjustments_with_actuals(adjustments, prstGeom.gd_lst)
         return adjustments
 
     def _rewrite_guides(self):
@@ -139,8 +139,8 @@ class AdjustmentCollection(object):
         """
         adjustments_by_name = dict((adj.name, adj) for adj in adjustments)
         for gd in guides:
-            name = gd.get('name')
-            actual = int(gd.get('fmla')[4:])
+            name = gd.name
+            actual = int(gd.fmla[4:])
             try:
                 adjustment = adjustments_by_name[name]
             except KeyError:
@@ -211,8 +211,10 @@ class AutoShapeType(object):
             return
         # raise on bad autoshape_type_id
         if autoshape_type_id not in autoshape_types:
-            tmpl = "no autoshape type with id %d in pptx.spec.autoshape_types"
-            raise KeyError(tmpl % autoshape_type_id)
+            raise KeyError(
+                "no autoshape type with id '%s' in pptx.spec.autoshape_types"
+                % autoshape_type_id
+            )
         # otherwise initialize new instance
         autoshape_type = autoshape_types[autoshape_type_id]
         self._autoshape_type_id = autoshape_type_id
@@ -221,7 +223,9 @@ class AutoShapeType(object):
 
     @property
     def autoshape_type_id(self):
-        """Integer identifier of this auto shape type"""
+        """
+        MSO_AUTO_SHAPE_TYPE enumeration value for this auto shape type
+        """
         return self._autoshape_type_id
 
     @property
@@ -238,11 +242,7 @@ class AutoShapeType(object):
         Return sequence of name, value tuples representing the adjustment
         value defaults for the auto shape type identified by *prst*.
         """
-        try:
-            autoshape_type_id = cls.id_from_prst(prst)
-        except KeyError:
-            return ()
-        return autoshape_types[autoshape_type_id]['avLst']
+        return autoshape_types[prst]['avLst']
 
     @property
     def desc(self):
@@ -288,16 +288,13 @@ class Shape(BaseShape):
     @property
     def auto_shape_type(self):
         """
-        Unique integer identifying the type of this auto shape, like
+        Enumeration value identifying the type of this auto shape, like
         ``MSO_SHAPE.ROUNDED_RECTANGLE``. Raises |ValueError| if this shape is
         not an auto shape.
         """
         if not self._sp.is_autoshape:
-            msg = "shape is not an auto shape"
-            raise ValueError(msg)
-        prst = self._sp.prst
-        auto_shape_type_id = AutoShapeType.id_from_prst(prst)
-        return auto_shape_type_id
+            raise ValueError("shape is not an auto shape")
+        return self._sp.prst
 
     @lazyproperty
     def fill(self):
