@@ -6,38 +6,36 @@ Table-related objects such as Table and Cell.
 
 from . import Subshape
 from ..dml.fill import FillFormat
-from ..enum.shapes import MSO_SHAPE_TYPE
-from .graphfrm import GraphicFrame
-from ..oxml.ns import qn
 from ..text import TextFrame
 from ..util import lazyproperty, to_unicode
 
 
-class Table(GraphicFrame):
+class Table(object):
     """
     A table shape. Not intended to be constructed directly, use
     :meth:`.Slide.shapes.add_table` to add a table to a slide.
     """
-    def __init__(self, graphicFrame, parent):
-        super(Table, self).__init__(graphicFrame, parent)
-        self._graphicFrame = graphicFrame
-        self._tbl_elm = graphicFrame[qn('a:graphic')].graphicData.tbl
-        self._rows = _RowCollection(self._tbl_elm, self)
-        self._columns = _ColumnCollection(self._tbl_elm, self)
+    def __init__(self, tbl, graphic_frame):
+        super(Table, self).__init__()
+        self._tbl = tbl
+        self._graphic_frame = graphic_frame
 
     def cell(self, row_idx, col_idx):
-        """Return table cell at *row_idx*, *col_idx* location"""
+        """
+        Return table cell at *row_idx*, *col_idx* location. Indexes are
+        zero-based, e.g. cell(0, 0) is the top, left cell.
+        """
         row = self.rows[row_idx]
         return row.cells[col_idx]
 
-    @property
+    @lazyproperty
     def columns(self):
         """
         Read-only reference to collection of |_Column| objects representing
         the table's columns. |_Column| objects are accessed using list
         notation, e.g. ``col = tbl.columns[0]``.
         """
-        return self._columns
+        return _ColumnCollection(self._tbl, self)
 
     @property
     def first_col(self):
@@ -46,7 +44,11 @@ class Table(GraphicFrame):
         column should be formatted differently, as for a side-heading column
         at the far left of the table.
         """
-        return self._tbl_elm.firstCol
+        return self._tbl.firstCol
+
+    @first_col.setter
+    def first_col(self, value):
+        self._tbl.firstCol = value
 
     @property
     def first_row(self):
@@ -54,7 +56,11 @@ class Table(GraphicFrame):
         Read/write boolean property which, when true, indicates the first
         row should be formatted differently, e.g. for column headings.
         """
-        return self._tbl_elm.firstRow
+        return self._tbl.firstRow
+
+    @first_row.setter
+    def first_row(self, value):
+        self._tbl.firstRow = value
 
     @property
     def horz_banding(self):
@@ -62,7 +68,11 @@ class Table(GraphicFrame):
         Read/write boolean property which, when true, indicates the rows of
         the table should appear with alternating shading.
         """
-        return self._tbl_elm.bandRow
+        return self._tbl.bandRow
+
+    @horz_banding.setter
+    def horz_banding(self, value):
+        self._tbl.bandRow = value
 
     @property
     def last_col(self):
@@ -71,7 +81,11 @@ class Table(GraphicFrame):
         column should be formatted differently, as for a row totals column at
         the far right of the table.
         """
-        return self._tbl_elm.lastCol
+        return self._tbl.lastCol
+
+    @last_col.setter
+    def last_col(self, value):
+        self._tbl.lastCol = value
 
     @property
     def last_row(self):
@@ -80,23 +94,11 @@ class Table(GraphicFrame):
         row should be formatted differently, as for a totals row at the
         bottom of the table.
         """
-        return self._tbl_elm.lastRow
+        return self._tbl.lastRow
 
-    @first_col.setter
-    def first_col(self, value):
-        self._tbl_elm.firstCol = bool(value)
-
-    @first_row.setter
-    def first_row(self, value):
-        self._tbl_elm.firstRow = bool(value)
-
-    @horz_banding.setter
-    def horz_banding(self, value):
-        self._tbl_elm.bandRow = bool(value)
-
-    @last_col.setter
-    def last_col(self, value):
-        self._tbl_elm.lastCol = bool(value)
+    @last_row.setter
+    def last_row(self, value):
+        self._tbl.lastRow = value
 
     def notify_height_changed(self):
         """
@@ -104,7 +106,7 @@ class Table(GraphicFrame):
         to recalculate its total height (as the sum of the row heights).
         """
         new_table_height = sum([row.height for row in self.rows])
-        self._graphicFrame.cy = new_table_height
+        self._graphic_frame.height = new_table_height
 
     def notify_width_changed(self):
         """
@@ -113,28 +115,23 @@ class Table(GraphicFrame):
         widths).
         """
         new_table_width = sum([col.width for col in self.columns])
-        self._graphicFrame.cx = new_table_width
-
-    @last_row.setter
-    def last_row(self, value):
-        self._tbl_elm.lastRow = bool(value)
+        self._graphic_frame.width = new_table_width
 
     @property
+    def part(self):
+        """
+        The package part containing this table.
+        """
+        return self._graphic_frame.part
+
+    @lazyproperty
     def rows(self):
         """
         Read-only reference to collection of |_Row| objects representing the
         table's rows. |_Row| objects are accessed using list notation, e.g.
         ``col = tbl.rows[0]``.
         """
-        return self._rows
-
-    @property
-    def shape_type(self):
-        """
-        Unique integer identifying the type of this shape, unconditionally
-        ``MSO_SHAPE_TYPE.TABLE`` in this case.
-        """
-        return MSO_SHAPE_TYPE.TABLE
+        return _RowCollection(self._tbl, self)
 
     @property
     def vert_banding(self):
@@ -142,11 +139,11 @@ class Table(GraphicFrame):
         Read/write boolean property which, when true, indicates the columns
         of the table should appear with alternating shading.
         """
-        return self._tbl_elm.bandCol
+        return self._tbl.bandCol
 
     @vert_banding.setter
     def vert_banding(self, value):
-        self._tbl_elm.bandCol = bool(value)
+        self._tbl.bandCol = value
 
 
 class _Cell(Subshape):
@@ -167,49 +164,55 @@ class _Cell(Subshape):
         return FillFormat.from_fill_parent(tcPr)
 
     @property
-    def margin_top(self):
+    def margin_left(self):
         """
-        Read/write integer value of top margin of cell in English Metric
-        Units (EMU). If assigned |None|, the default value is used, 0.1
+        Read/write integer value of left margin of cell as a |BaseLength|
+        value object. If assigned |None|, the default value is used, 0.1
         inches for left and right margins and 0.05 inches for top and bottom.
         """
-        return self._tc.marT
+        return self._tc.marL
+
+    @margin_left.setter
+    def margin_left(self, margin_left):
+        self._validate_margin_value(margin_left)
+        self._tc.marL = margin_left
 
     @property
     def margin_right(self):
-        """Right margin of cell"""
+        """
+        Right margin of cell.
+        """
         return self._tc.marR
 
-    @property
-    def margin_bottom(self):
-        """Bottom margin of cell"""
-        return self._tc.marB
-
-    @property
-    def margin_left(self):
-        """Left margin of cell"""
-        return self._tc.marL
-
-    @margin_top.setter
-    def margin_top(self, margin_top):
-        self._validate_margin_value(margin_top)
-        self._tc.marT = margin_top
-
     @margin_right.setter
     def margin_right(self, margin_right):
         self._validate_margin_value(margin_right)
         self._tc.marR = margin_right
 
+    @property
+    def margin_top(self):
+        """
+        Top margin of cell.
+        """
+        return self._tc.marT
+
+    @margin_top.setter
+    def margin_top(self, margin_top):
+        self._validate_margin_value(margin_top)
+        self._tc.marT = margin_top
+
+    @property
+    def margin_bottom(self):
+        """
+        Bottom margin of cell.
+        """
+        return self._tc.marB
+
     @margin_bottom.setter
     def margin_bottom(self, margin_bottom):
         self._validate_margin_value(margin_bottom)
         self._tc.marB = margin_bottom
 
-    @margin_left.setter
-    def margin_left(self, margin_left):
-        self._validate_margin_value(margin_left)
-        self._tc.marL = margin_left
-
     def text(self, text):
         """
         Replace all text in cell with single run containing *text*
@@ -271,25 +274,18 @@ class _Column(Subshape):
         super(_Column, self).__init__(parent)
         self._gridCol = gridCol
 
-    def _get_width(self):
+    @property
+    def width(self):
         """
-        Return width of column in EMU
+        Width of column in EMU.
         """
-        return int(self._gridCol.get('w'))
+        return self._gridCol.w
 
-    def _set_width(self, width):
-        """
-        Set column width to *width*, a positive integer value.
-        """
-        if not isinstance(width, int) or width < 0:
-            msg = "column width must be positive integer"
-            raise ValueError(msg)
-        self._gridCol.set('w', str(width))
+    @width.setter
+    def width(self, width):
+        self._gridCol.w = width
         self._parent.notify_width_changed()
 
-    #: Read-write integer width of this column in English Metric Units (EMU).
-    width = property(_get_width, _set_width)
-
 
 class _Row(Subshape):
     """
@@ -298,7 +294,6 @@ class _Row(Subshape):
     def __init__(self, tr, parent):
         super(_Row, self).__init__(parent)
         self._tr = tr
-        self._cells = _CellCollection(tr, self)
 
     @property
     def cells(self):
@@ -306,27 +301,20 @@ class _Row(Subshape):
         Read-only reference to collection of cells in row. An individual cell
         is referenced using list notation, e.g. ``cell = row.cells[0]``.
         """
-        return self._cells
+        return _CellCollection(self._tr, self)
 
-    def _get_height(self):
+    @property
+    def height(self):
         """
-        Return height of row in EMU
+        Height of row in EMU.
         """
-        return int(self._tr.get('h'))
+        return self._tr.h
 
-    def _set_height(self, height):
-        """
-        Set row height to *height*, a positive integer value.
-        """
-        if not isinstance(height, int) or height < 0:
-            msg = "row height must be positive integer"
-            raise ValueError(msg)
-        self._tr.set('h', str(height))
+    @height.setter
+    def height(self, height):
+        self._tr.h = height
         self._parent.notify_height_changed()
 
-    #: Read/write integer height of this row in English Metric Units (EMU).
-    height = property(_get_height, _set_height)
-
 
 class _CellCollection(Subshape):
     """
@@ -337,35 +325,43 @@ class _CellCollection(Subshape):
         self._tr = tr
 
     def __getitem__(self, idx):
-        """Provides indexed access, (e.g. 'cells[0]')."""
-        if idx < 0 or idx >= len(self._tr.tc):
+        """
+        Provides indexed access, (e.g. 'cells[0]').
+        """
+        if idx < 0 or idx >= len(self._tr.tc_lst):
             msg = "cell index [%d] out of range" % idx
             raise IndexError(msg)
-        return _Cell(self._tr.tc[idx], self)
+        return _Cell(self._tr.tc_lst[idx], self)
 
     def __len__(self):
-        """Supports len() function (e.g. 'len(cells) == 1')."""
-        return len(self._tr.tc)
+        """
+        Supports len() function (e.g. 'len(cells) == 1').
+        """
+        return len(self._tr.tc_lst)
 
 
 class _ColumnCollection(Subshape):
     """
     Sequence of table columns.
     """
-    def __init__(self, tbl_elm, parent):
+    def __init__(self, tbl, parent):
         super(_ColumnCollection, self).__init__(parent)
-        self._tbl_elm = tbl_elm
+        self._tbl = tbl
 
     def __getitem__(self, idx):
-        """Provides indexed access, (e.g. 'columns[0]')."""
-        if idx < 0 or idx >= len(self._tbl_elm.tblGrid.gridCol):
+        """
+        Provides indexed access, (e.g. 'columns[0]').
+        """
+        if idx < 0 or idx >= len(self._tbl.tblGrid.gridCol_lst):
             msg = "column index [%d] out of range" % idx
             raise IndexError(msg)
-        return _Column(self._tbl_elm.tblGrid.gridCol[idx], self)
+        return _Column(self._tbl.tblGrid.gridCol_lst[idx], self)
 
     def __len__(self):
-        """Supports len() function (e.g. 'len(columns) == 1')."""
-        return len(self._tbl_elm.tblGrid.gridCol)
+        """
+        Supports len() function (e.g. 'len(columns) == 1').
+        """
+        return len(self._tbl.tblGrid.gridCol_lst)
 
     def notify_width_changed(self):
         """
@@ -378,20 +374,24 @@ class _RowCollection(Subshape):
     """
     Sequence of table rows.
     """
-    def __init__(self, tbl_elm, parent):
+    def __init__(self, tbl, parent):
         super(_RowCollection, self).__init__(parent)
-        self._tbl_elm = tbl_elm
+        self._tbl = tbl
 
     def __getitem__(self, idx):
-        """Provides indexed access, (e.g. 'rows[0]')."""
-        if idx < 0 or idx >= len(self._tbl_elm.tr):
+        """
+        Provides indexed access, (e.g. 'rows[0]').
+        """
+        if idx < 0 or idx >= len(self):
             msg = "row index [%d] out of range" % idx
             raise IndexError(msg)
-        return _Row(self._tbl_elm.tr[idx], self)
+        return _Row(self._tbl.tr_lst[idx], self)
 
     def __len__(self):
-        """Supports len() function (e.g. 'len(rows) == 1')."""
-        return len(self._tbl_elm.tr)
+        """
+        Supports len() function (e.g. 'len(rows) == 1').
+        """
+        return len(self._tbl.tr_lst)
 
     def notify_height_changed(self):
         """
