@@ -6,12 +6,10 @@ Text-related objects such as TextFrame and Paragraph.
 
 from .dml.fill import FillFormat
 from .enum.dml import MSO_FILL
-from .enum.text import MSO_ANCHOR, PP_ALIGN
 from .opc.constants import RELATIONSHIP_TYPE as RT
-from .oxml.shared import Element, get_or_add
-from .oxml.ns import _nsmap, qn
+from .oxml.simpletypes import ST_TextWrappingType
 from .shapes import Subshape
-from .util import Emu, lazyproperty, to_unicode
+from .util import Centipoints, Emu, lazyproperty, to_unicode
 
 
 class TextFrame(Subshape):
@@ -29,9 +27,7 @@ class TextFrame(Subshape):
         Return new |_Paragraph| instance appended to the sequence of
         paragraphs contained in this text frame.
         """
-        # <a:p> elements are last in txBody, so can simply append new one
-        p = Element('a:p')
-        self._txBody.append(p)
+        p = self._txBody.add_p()
         return _Paragraph(p, self)
 
     @property
@@ -53,8 +49,7 @@ class TextFrame(Subshape):
         """
         Remove all paragraphs except one empty one.
         """
-        p_list = self._txBody.xpath('./a:p', namespaces=_nsmap)
-        for p in p_list[1:]:
+        for p in self._txBody.p_lst[1:]:
             self._txBody.remove(p)
         p = self.paragraphs[0]
         p.clear()
@@ -107,7 +102,7 @@ class TextFrame(Subshape):
         paragraphs in this text frame. A text frame always contains at least
         one paragraph.
         """
-        return tuple([_Paragraph(p, self) for p in self._txBody[qn('a:p')]])
+        return tuple([_Paragraph(p, self) for p in self._txBody.p_lst])
 
     def _set_text(self, text):
         """Replace all text in text frame with single run containing *text*"""
@@ -126,9 +121,8 @@ class TextFrame(Subshape):
         """
         Set ``anchor`` attribute of ``<a:bodyPr>`` element
         """
-        anchor = MSO_ANCHOR.to_xml(value)
-        bodyPr = get_or_add(self._txBody, 'a:bodyPr')
-        bodyPr.set('anchor', anchor)
+        bodyPr = self._txBody.bodyPr
+        bodyPr.anchor = value
 
     #: Write-only. Assignment to *vertical_anchor* sets the vertical
     #: alignment of the text frame to top, middle, or bottom. Valid values are
@@ -146,27 +140,30 @@ class TextFrame(Subshape):
         removed entirely and the text frame wrapping behavior to be inherited
         from a parent element.
         """
-        value_map = {'square': True, 'none': False, None: None}
-        bodyPr = get_or_add(self._txBody, 'a:bodyPr')
-        value = bodyPr.get('wrap')
-        return value_map[value]
+        return {
+            ST_TextWrappingType.SQUARE: True,
+            ST_TextWrappingType.NONE:   False,
+            None:                       None
+        }[self._txBody.bodyPr.wrap]
 
     @word_wrap.setter
     def word_wrap(self, value):
-        value_map = {True: 'square', False: 'none'}
-        bodyPr = get_or_add(self._txBody, 'a:bodyPr')
-        if value is None:
-            if 'wrap' in bodyPr.attrib:
-                del bodyPr.attrib['wrap']
-            return
-        bodyPr.set('wrap', value_map[value])
+        if value not in (True, False, None):
+            raise ValueError(
+                "assigned value must be True, False, or None, got %s" % value
+            )
+        self._txBody.bodyPr.wrap = {
+            True:  ST_TextWrappingType.SQUARE,
+            False: ST_TextWrappingType.NONE,
+            None:  None
+        }[value]
 
     @property
     def _bodyPr(self):
         return self._txBody.bodyPr
 
 
-class _Font(object):
+class Font(object):
     """
     Character properties object, providing font size, font name, bold,
     italic, etc. Corresponds to ``<a:rPr>`` child element of a run. Also
@@ -174,13 +171,13 @@ class _Font(object):
     ``<a:defRPr>`` in list style elements.
     """
     def __init__(self, rPr):
-        super(_Font, self).__init__()
+        super(Font, self).__init__()
         self._rPr = rPr
 
     @property
     def bold(self):
         """
-        Get or set boolean bold value of |_Font|, e.g.
+        Get or set boolean bold value of |Font|, e.g.
         ``paragraph.font.bold = True``. If set to |None|, the bold setting is
         cleared and is inherited from an enclosing shape's setting, or a
         setting in a style or master. Returns None if no bold attribute is
@@ -214,7 +211,7 @@ class _Font(object):
     @property
     def italic(self):
         """
-        Get or set boolean italic value of |_Font| instance, with the same
+        Get or set boolean italic value of |Font| instance, with the same
         behaviors as bold with respect to None values.
         """
         return self._rPr.i
@@ -226,7 +223,7 @@ class _Font(object):
     @property
     def name(self):
         """
-        Get or set the typeface name for this |_Font| instance, causing the
+        Get or set the typeface name for this |Font| instance, causing the
         text it controls to appear in the named font, if a matching font is
         found. Returns |None| if the typeface is currently inherited from the
         theme. Setting it to |None| removes any override of the theme
@@ -240,7 +237,7 @@ class _Font(object):
     @name.setter
     def name(self, value):
         if value is None:
-            self._rPr.remove_latin()
+            self._rPr._remove_latin()
         else:
             latin = self._rPr.get_or_add_latin()
             latin.typeface = value
@@ -260,11 +257,15 @@ class _Font(object):
             >> font.size.pt
             24.0
         """
-        return self._rPr.sz
+        sz = self._rPr.sz
+        if sz is None:
+            return None
+        return Centipoints(sz)
 
     @size.setter
     def size(self, emu):
-        self._rPr.sz = Emu(emu)
+        sz = Emu(emu).centipoints
+        self._rPr.sz = sz
 
 
 class _Hyperlink(Subshape):
@@ -305,7 +306,7 @@ class _Hyperlink(Subshape):
     def _remove_hlinkClick(self):
         assert self._hlinkClick is not None
         self.part.drop_rel(self._hlinkClick.rId)
-        self._rPr.hlinkClick = None
+        self._rPr._remove_hlinkClick()
 
 
 class _Paragraph(Subshape):
@@ -331,12 +332,11 @@ class _Paragraph(Subshape):
         paragraph has no alignment setting and its effective value is
         inherited from a higher-level object.
         """
-        return PP_ALIGN.from_xml(self._pPr.algn)
+        return self._pPr.algn
 
     @alignment.setter
     def alignment(self, alignment):
-        algn = PP_ALIGN.to_xml(alignment)
-        self._pPr.algn = algn
+        self._pPr.algn = alignment
 
     def clear(self):
         """
@@ -348,13 +348,13 @@ class _Paragraph(Subshape):
     @property
     def font(self):
         """
-        |_Font| object containing default character properties for the runs in
+        |Font| object containing default character properties for the runs in
         this paragraph. These character properties override default properties
         inherited from parent objects such as the text frame the paragraph is
         contained in and they may be overridden by character properties set at
         the run level.
         """
-        return _Font(self._defRPr)
+        return Font(self._defRPr)
 
     @property
     def level(self):
@@ -364,15 +364,11 @@ class _Paragraph(Subshape):
         default value. Indentation level is most commonly encountered in a
         bulleted list, as is found on a word bullet slide.
         """
-        # return self._pPr.lvl
-        return int(self._pPr.get('lvl', 0))
+        return self._pPr.lvl
 
     @level.setter
     def level(self, level):
-        if not isinstance(level, int) or level < 0 or level > 8:
-            msg = "paragraph level must be integer between 0 and 8 inclusive"
-            raise ValueError(msg)
-        self._pPr.set('lvl', str(level))
+        self._pPr.lvl = level
 
     @property
     def runs(self):
@@ -380,10 +376,8 @@ class _Paragraph(Subshape):
         Immutable sequence of |_Run| instances corresponding to the runs in
         this paragraph.
         """
-        xpath = './a:r'
-        r_elms = self._p.xpath(xpath, namespaces=_nsmap)
         runs = []
-        for r in r_elms:
+        for r in self._p.r_lst:
             runs.append(_Run(r, self))
         return tuple(runs)
 
@@ -431,14 +425,14 @@ class _Run(Subshape):
     @property
     def font(self):
         """
-        |_Font| instance containing run-level character properties for the
+        |Font| instance containing run-level character properties for the
         text in this run. Character properties can be and perhaps most often
         are inherited from parent objects such as the paragraph and slide
         layout the run is contained in. Only those specifically overridden at
         the run level are contained in the font object.
         """
         rPr = self._r.get_or_add_rPr()
-        return _Font(rPr)
+        return Font(rPr)
 
     @lazyproperty
     def hyperlink(self):
@@ -465,5 +459,7 @@ class _Run(Subshape):
 
     @text.setter
     def text(self, str):
-        """Set the text of this run to *str*."""
-        self._r.t._setText(to_unicode(str))
+        """
+        Set the text of this run to *str*.
+        """
+        self._r.t.text = to_unicode(str)
