@@ -13,21 +13,21 @@ from pptx.dml.fill import FillFormat
 from pptx.enum.text import MSO_ANCHOR, MSO_AUTO_SIZE, PP_ALIGN
 from pptx.opc.constants import RELATIONSHIP_TYPE as RT
 from pptx.opc.package import Part
-from pptx.oxml import parse_xml_bytes
-from pptx.oxml.ns import nsdecls, _nsmap as nsmap
+from pptx.oxml import parse_xml
+from pptx.oxml.ns import nsdecls
 from pptx.oxml.text import (
     CT_RegularTextRun, CT_TextCharacterProperties, CT_TextParagraph
 )
-from pptx.text import _Font, _Hyperlink, _Paragraph, _Run, TextFrame
+from pptx.text import Font, _Hyperlink, _Paragraph, _Run, TextFrame
 from pptx.util import Inches, Pt
 
 from .oxml.unitdata.text import (
     a_bodyPr, a_latin, a_txBody, a_noAutofit, a_normAutofit, a_p, a_pPr, a_t,
     an_hlinkClick, an_r, an_rPr, an_spAutoFit
 )
-from .unitutil import (
-    absjoin, actual_xml, class_mock, instance_mock, loose_mock,
-    parse_xml_file, property_mock, test_file_dir
+from .unitutil.file import absjoin, parse_xml_file, test_file_dir
+from .unitutil.mock import (
+    class_mock, instance_mock, loose_mock, property_mock
 )
 
 
@@ -40,7 +40,7 @@ class DescribeTextFrame(object):
     def it_can_change_its_autosize_setting(self, autosize_set_fixture):
         textframe, value, expected_xml = autosize_set_fixture
         textframe.auto_size = value
-        assert actual_xml(textframe._txBody) == expected_xml
+        assert textframe._txBody.xml == expected_xml
 
     def it_knows_the_number_of_paragraphs_it_contains(
             self, txBody, txBody_with_2_paras):
@@ -51,13 +51,13 @@ class DescribeTextFrame(object):
             self, txBody, txBody_with_2_paras_xml):
         textframe = TextFrame(txBody, None)
         textframe.add_paragraph()
-        assert actual_xml(textframe._txBody) == txBody_with_2_paras_xml
+        assert textframe._txBody.xml == txBody_with_2_paras_xml
 
     def it_can_replace_the_text_it_contains(
             self, txBody, txBody_with_text_xml):
         textframe = TextFrame(txBody, None)
         textframe.text = 'foobar'
-        assert actual_xml(txBody) == txBody_with_text_xml
+        assert txBody.xml == txBody_with_text_xml
 
     def it_can_get_its_margin_settings(
             self, txBody, txBody_with_lIns, txBody_with_tIns,
@@ -87,29 +87,29 @@ class DescribeTextFrame(object):
 
         textframe = TextFrame(txBody_bldr.element, None)
         textframe.margin_left = Inches(0.01)
-        assert actual_xml(textframe._txBody) == txBody_with_lIns_xml
+        assert textframe._txBody.xml == txBody_with_lIns_xml
 
         textframe = TextFrame(txBody_bldr.element, None)
         textframe.margin_top = Inches(0.02)
-        assert actual_xml(textframe._txBody) == txBody_with_tIns_xml
+        assert textframe._txBody.xml == txBody_with_tIns_xml
 
         textframe = TextFrame(txBody_bldr.element, None)
         textframe.margin_right = Inches(0.03)
-        assert actual_xml(textframe._txBody) == txBody_with_rIns_xml
+        assert textframe._txBody.xml == txBody_with_rIns_xml
 
         textframe = TextFrame(txBody_bldr.element, None)
         textframe.margin_bottom = Inches(0.04)
-        assert actual_xml(textframe._txBody) == txBody_with_bIns_xml
+        assert textframe._txBody.xml == txBody_with_bIns_xml
 
     def it_raises_on_attempt_to_set_margin_to_non_int(self, textframe):
-        with pytest.raises(ValueError):
+        with pytest.raises(TypeError):
             textframe.margin_bottom = '0.1'
 
     def it_can_change_its_vertical_anchor_setting(
             self, txBody, txBody_with_anchor_ctr_xml):
         textframe = TextFrame(txBody, None)
         textframe.vertical_anchor = MSO_ANCHOR.MIDDLE
-        assert actual_xml(textframe._txBody) == txBody_with_anchor_ctr_xml
+        assert textframe._txBody.xml == txBody_with_anchor_ctr_xml
 
     def it_can_change_the_word_wrap_setting(
             self, txBody, txBody_with_wrap_on_xml, txBody_with_wrap_off_xml,
@@ -118,15 +118,15 @@ class DescribeTextFrame(object):
         assert textframe.word_wrap is None
 
         textframe.word_wrap = True
-        assert actual_xml(textframe._txBody) == txBody_with_wrap_on_xml
+        assert textframe._txBody.xml == txBody_with_wrap_on_xml
         assert textframe.word_wrap is True
 
         textframe.word_wrap = False
-        assert actual_xml(textframe._txBody) == txBody_with_wrap_off_xml
+        assert textframe._txBody.xml == txBody_with_wrap_off_xml
         assert textframe.word_wrap is False
 
         textframe.word_wrap = None
-        assert actual_xml(textframe._txBody) == txBody_xml
+        assert textframe._txBody.xml == txBody_xml
         assert textframe.word_wrap is None
 
     def it_knows_the_part_it_belongs_to(self, textframe_with_parent_):
@@ -345,7 +345,7 @@ class DescribeTextFrame(object):
         )
 
 
-class Describe_Font(object):
+class DescribeFont(object):
 
     def it_knows_the_bold_setting(self, font, bold_font, bold_off_font):
         assert font.bold is None
@@ -354,15 +354,15 @@ class Describe_Font(object):
 
     def it_can_change_the_bold_setting(
             self, font, bold_rPr_xml, bold_off_rPr_xml, rPr_xml):
-        assert actual_xml(font._rPr) == rPr_xml
+        assert font._rPr.xml == rPr_xml
         font.bold = None
-        assert actual_xml(font._rPr) == rPr_xml
+        assert font._rPr.xml == rPr_xml
         font.bold = True
-        assert actual_xml(font._rPr) == bold_rPr_xml
+        assert font._rPr.xml == bold_rPr_xml
         font.bold = False
-        assert actual_xml(font._rPr) == bold_off_rPr_xml
+        assert font._rPr.xml == bold_off_rPr_xml
         font.bold = None
-        assert actual_xml(font._rPr) == rPr_xml
+        assert font._rPr.xml == rPr_xml
 
     def it_has_a_color(self, font):
         assert isinstance(font.color, ColorFormat)
@@ -377,15 +377,15 @@ class Describe_Font(object):
 
     def it_can_change_the_italic_setting(
             self, font, italic_rPr_xml, italic_off_rPr_xml, rPr_xml):
-        assert actual_xml(font._rPr) == rPr_xml
+        assert font._rPr.xml == rPr_xml
         font.italic = None  # important to test None to None transition
-        assert actual_xml(font._rPr) == rPr_xml
+        assert font._rPr.xml == rPr_xml
         font.italic = True
-        assert actual_xml(font._rPr) == italic_rPr_xml
+        assert font._rPr.xml == italic_rPr_xml
         font.italic = False
-        assert actual_xml(font._rPr) == italic_off_rPr_xml
+        assert font._rPr.xml == italic_off_rPr_xml
         font.italic = None
-        assert actual_xml(font._rPr) == rPr_xml
+        assert font._rPr.xml == rPr_xml
 
     def it_knows_its_latin_typeface(self, typeface_get_fixture):
         font, typeface = typeface_get_fixture
@@ -394,7 +394,7 @@ class Describe_Font(object):
     def it_can_change_its_latin_typeface(self, typeface_set_fixture):
         font, typeface, rPr_with_latin_xml = typeface_set_fixture
         font.name = typeface
-        assert actual_xml(font._rPr) == rPr_with_latin_xml
+        assert font._rPr.xml == rPr_with_latin_xml
 
     def it_knows_the_font_size(self, size_get_fixture):
         font, expected_size = size_get_fixture
@@ -403,7 +403,7 @@ class Describe_Font(object):
     def it_can_set_the_font_size(self, font):
         font.size = Pt(24)
         expected_xml = an_rPr().with_nsdecls().with_sz(2400).xml()
-        assert actual_xml(font._rPr) == expected_xml
+        assert font._rPr.xml == expected_xml
 
     # fixtures ---------------------------------------------
 
@@ -416,7 +416,7 @@ class Describe_Font(object):
         rPr_bldr = an_rPr().with_nsdecls()
         if sz_val is not None:
             rPr_bldr.with_sz(sz_val)
-        font = _Font(rPr_bldr.element)
+        font = Font(rPr_bldr.element)
         return font, expected_size
 
     @pytest.fixture(params=[None, 'Foobar Light'])
@@ -426,7 +426,7 @@ class Describe_Font(object):
         if typeface is not None:
             rPr_bldr.with_child(a_latin().with_typeface(typeface))
         rPr = rPr_bldr.element
-        font = _Font(rPr)
+        font = Font(rPr)
         return font, typeface
 
     @pytest.fixture(params=[
@@ -442,7 +442,7 @@ class Describe_Font(object):
         if before_typeface is not None:
             rPr_bldr.with_child(a_latin().with_typeface(before_typeface))
         rPr = rPr_bldr.element
-        font = _Font(rPr)
+        font = Font(rPr)
         # expected XML
         rPr_bldr = an_rPr().with_nsdecls()
         if after_typeface is not None:
@@ -455,12 +455,12 @@ class Describe_Font(object):
     @pytest.fixture
     def bold_font(self):
         bold_rPr = an_rPr().with_nsdecls().with_b(1).element
-        return _Font(bold_rPr)
+        return Font(bold_rPr)
 
     @pytest.fixture
     def bold_off_font(self):
         bold_off_rPr = an_rPr().with_nsdecls().with_b(0).element
-        return _Font(bold_off_rPr)
+        return Font(bold_off_rPr)
 
     @pytest.fixture
     def bold_off_rPr_xml(self):
@@ -473,17 +473,17 @@ class Describe_Font(object):
     @pytest.fixture
     def font(self):
         rPr = an_rPr().with_nsdecls().element
-        return _Font(rPr)
+        return Font(rPr)
 
     @pytest.fixture
     def italic_font(self):
         italic_rPr = an_rPr().with_nsdecls().with_i(1).element
-        return _Font(italic_rPr)
+        return Font(italic_rPr)
 
     @pytest.fixture
     def italic_off_font(self):
         italic_rPr = an_rPr().with_nsdecls().with_i(0).element
-        return _Font(italic_rPr)
+        return Font(italic_rPr)
 
     @pytest.fixture
     def italic_off_rPr_xml(self):
@@ -515,20 +515,20 @@ class Describe_Hyperlink(object):
         hlink.part.relate_to.assert_called_once_with(
             url, RT.HYPERLINK, is_external=True
         )
-        assert actual_xml(hlink._rPr) == rPr_with_hlinkClick_xml
+        assert hlink._rPr.xml == rPr_with_hlinkClick_xml
         assert hlink.address == url
 
     def it_can_remove_the_hyperlink(self, remove_hlink_fixture_):
         hlink, rPr_xml, rId = remove_hlink_fixture_
         hlink.address = None
-        assert actual_xml(hlink._rPr) == rPr_xml
+        assert hlink._rPr.xml == rPr_xml
         hlink.part.drop_rel.assert_called_once_with(rId)
 
     def it_should_remove_the_hyperlink_when_url_set_to_empty_string(
             self, remove_hlink_fixture_):
         hlink, rPr_xml, rId = remove_hlink_fixture_
         hlink.address = ''
-        assert actual_xml(hlink._rPr) == rPr_xml
+        assert hlink._rPr.xml == rPr_xml
         hlink.part.drop_rel.assert_called_once_with(rId)
 
     def it_can_change_the_target_url(self, change_hlink_fixture_):
@@ -537,7 +537,7 @@ class Describe_Hyperlink(object):
         # exercise ---------------------
         hlink.address = new_url
         # verify -----------------------
-        assert actual_xml(hlink._rPr) == new_rPr_xml
+        assert hlink._rPr.xml == new_rPr_xml
         hlink.part.drop_rel.assert_called_once_with(rId_existing)
         hlink.part.relate_to.assert_called_once_with(
             new_url, RT.HYPERLINK, is_external=True
@@ -616,7 +616,7 @@ class Describe_Hyperlink(object):
 
     @pytest.fixture
     def rPr_xml(self):
-        return an_rPr().with_nsdecls().xml()
+        return an_rPr().with_nsdecls('a', 'r').xml()
 
     @pytest.fixture
     def url(self):
@@ -631,7 +631,7 @@ class Describe_Paragraph(object):
 
     def it_can_add_a_run(self, paragraph, p_with_r_xml):
         run = paragraph.add_run()
-        assert actual_xml(paragraph._p) == p_with_r_xml
+        assert paragraph._p.xml == p_with_r_xml
         assert isinstance(run, _Run)
 
     def it_knows_the_alignment_setting_of_the_paragraph(
@@ -641,7 +641,7 @@ class Describe_Paragraph(object):
 
     def it_can_change_its_alignment_setting(self, paragraph):
         paragraph.alignment = PP_ALIGN.LEFT
-        assert paragraph._pPr.algn == 'l'
+        assert paragraph._pPr.algn == PP_ALIGN.LEFT
         paragraph.alignment = None
         assert paragraph._pPr.algn is None
 
@@ -666,7 +666,7 @@ class Describe_Paragraph(object):
         # exercise ---------------------
         paragraph_with_text.level = 2
         # verify -----------------------
-        assert actual_xml(paragraph_with_text._p) == expected_xml
+        assert paragraph_with_text._p.xml == expected_xml
 
     def test_level_default_is_zero(self, paragraph_with_text):
         """_Paragraph.level defaults to zero on no lvl attribute"""
@@ -681,8 +681,12 @@ class Describe_Paragraph(object):
         assert paragraph_with_text.level == 5
 
     def test_level_raises_on_bad_value(self, paragraph_with_text):
-        """_Paragraph.level raises on attempt to assign invalid value"""
-        test_cases = ('0', -1, 9)
+        test_cases = ('0', 'foobar', 7.5)
+        for value in test_cases:
+            with pytest.raises(TypeError):
+                paragraph_with_text.level = value
+
+        test_cases = (-1, 9)
         for value in test_cases:
             with pytest.raises(ValueError):
                 paragraph_with_text.level = value
@@ -738,11 +742,11 @@ class Describe_Paragraph(object):
 
     @pytest.fixture
     def Font_(self, request):
-        return class_mock(request, 'pptx.text._Font')
+        return class_mock(request, 'pptx.text.Font')
 
     @pytest.fixture
     def pList(self, sld, xpath):
-        return sld.xpath(xpath, namespaces=nsmap)
+        return sld.xpath(xpath)
 
     @pytest.fixture
     def p_(self, request):
@@ -759,7 +763,7 @@ class Describe_Paragraph(object):
 
     @pytest.fixture
     def p_with_text(self, p_with_text_xml):
-        return parse_xml_bytes(p_with_text_xml)
+        return parse_xml(p_with_text_xml)
 
     @pytest.fixture
     def p_with_text_xml(self, test_text):
@@ -800,11 +804,11 @@ class Describe_Paragraph(object):
 class Describe_Run(object):
 
     def it_provides_access_to_the_font_of_the_run(
-            self, r_, _Font_, rPr_, font_):
+            self, r_, Font_, rPr_, font_):
         run = _Run(r_, None)
         font = run.font
         r_.get_or_add_rPr.assert_called_once_with()
-        _Font_.assert_called_once_with(rPr_)
+        Font_.assert_called_once_with(rPr_)
         assert font == font_
 
     def it_provides_access_to_the_hyperlink_of_the_run(self, run):
@@ -821,18 +825,18 @@ class Describe_Run(object):
     # fixtures ---------------------------------------------
 
     @pytest.fixture
-    def _Font_(self, request, font_):
-        _Font_ = class_mock(request, 'pptx.text._Font')
-        _Font_.return_value = font_
-        return _Font_
+    def Font_(self, request, font_):
+        Font_ = class_mock(request, 'pptx.text.Font')
+        Font_.return_value = font_
+        return Font_
 
     @pytest.fixture
     def font_(self, request):
-        return instance_mock(request, 'pptx.text._Font')
+        return instance_mock(request, 'pptx.text.Font')
 
     @pytest.fixture
     def r(self, r_xml):
-        return parse_xml_bytes(r_xml)
+        return parse_xml(r_xml)
 
     @pytest.fixture
     def rPr_(self, request):
@@ -840,7 +844,7 @@ class Describe_Run(object):
 
     @pytest.fixture
     def r_(self, request, rPr_):
-        r_ = instance_mock(request, CT_RegularTextRun)
+        r_ = loose_mock(request, CT_RegularTextRun)
         r_.get_or_add_rPr.return_value = rPr_
         return r_
 
